# Infini 2

<!-- start index -->

## 简述

Infini 2 是一个先进的内容输入输出流标准框架，它的诞生源于对于平台机器人的代码复用问题，以及指令的动态解析问题。Infini 2 的规则包是可热插拔的，它以使用 Infini 框架的规则包为最小热插拔单元，以`输入→预拦截→业务函数→内容生成→内容拦截→输出`为一整套 Infini 输入输出流程式，规则包可以定制化的注册任一流程层次的处理函数。

Infini 2 同样是**跨平台跨框架**的。你可以在任何支持 Python 的平台运行 Infini，同样的，你在对接平台时，可以选用任何框架来适配 Infini 2，例如[`Nonebot2`](https://nonebot.dev/)、[`OlivOS`](https://doc.olivos.wiki/)和[`iamai`](https://github.com/retrofor/iamai/)等，而这些框架都是跨平台和跨协议的，这意味着 Infini 2 同样是跨平台和跨协议支持的。Infini 可能将在未来版本支持直接对接平台协议。

Infini 2 所有层次的业务函数都是依照参数名进行**依赖注入**的，你可以动态的选择你所需要的注入参数。由于先进的架构特性，Infini 2 可以省去大量的开发时间，节约开发成本。同时由于其轻量的输入输出流程式，它拥有较低的学习成本。

## 开发者

欢迎任何遵循社区常态的开发者参与 Infini 2 的开发和社区构建，欢迎加入[Infini 2 公测 QQ 群: 231892965](http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=B90zg667S_HvfwsG3V3iVGumtLNjY3CN&authKey=H%2Bw4RqjV5sjAmUUbUkUlQsYQGcjdDd0nW%2BBnnTRCL1duIis8RJnj5qTSyN7e7jds&noverify=0&group_code=231892965)。

## 版权

水系 × [浊莲](https://github.com/noctisynth)依照 MIT 协议开源 Infini。

<!-- end index -->
